@@ -46,30 +46,31 @@ class EvaluatePrequential(StreamEvaluator):
     metrics: list, optional (Default: ['accuracy', 'kappa'])
         | The list of metrics to track during the evaluation. Also defines the metrics that will be displayed in plots
           and/or logged into the output file. Valid options are
-        | *Classification*
+        | **Classification**
         | 'accuracy'
         | 'kappa'
         | 'kappa_t'
         | 'kappa_m'
         | 'true_vs_predicted'
-        | 'precision'
-        | 'recall'
-        | 'f1'
-        | 'gmean'
-        | *Multi-target Classification*
+        | 'precision'*
+        | 'recall'*
+        | 'f1'*
+        | 'gmean'*
+        | * binary-classification *only*
+        | **Multi-target Classification**
         | 'hamming_score'
         | 'hamming_loss'
         | 'exact_match'
         | 'j_index'
-        | *Regression*
+        | **Regression**
         | 'mean_square_error'
         | 'mean_absolute_error'
         | 'true_vs_predicted'
-        | *Multi-target Regression*
+        | **Multi-target Regression**
         | 'average_mean_squared_error'
         | 'average_mean_absolute_error'
         | 'average_root_mean_square_error'
-        | *Experimental*
+        | **Experimental**
         | 'running_time'
         | 'model_size'
 
